==> tigase-server-5.1.0-sources.jar: tigase/server/bosh/BoshSessionTaskHandler.java <==
/*  Tigase Jabber/XMPP Server
 *  Copyright (C) 2004-2012 "Artur Hefczyc" <artur.hefczyc@tigase.org>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. Look for COPYING file in the top folder.
 * If not, see http://www.gnu.org/licenses/.
 *
 * $Rev: 2996 $
 * Last modified by $Author: wojtek $
 * $Date: 2012-08-21 00:29:57 +0200 (Tue, 21 Aug 2012) $
 */
package tigase.server.bosh;

import java.util.TimerTask;
import tigase.server.Packet;
import tigase.xmpp.BareJID;

/**
 * Describe interface BoshSessionTaskHandler here.
 *
 *
 * Created: Sat Aug  4 10:39:21 2007
 *
 * @author <a href="mailto:artur.hefczyc@tigase.org">Artur Hefczyc</a>
 * @version $Rev: 2996 $
 */
public interface BoshSessionTaskHandler {

	TimerTask scheduleTask(BoshSession bs, long delay);

	void cancelTask(TimerTask bs);

	void writeRawData(BoshIOService ios, String data);

	boolean addOutStreamOpen(Packet packet, BoshSession bs);

	boolean addOutStreamClosed(Packet packet, BoshSession bs);

        BareJID getSeeOtherHostForJID(BareJID userId);        
}

==> tigase-server-5.2.3-sources.jar: tigase/server/bosh/BoshSessionTaskHandler.java <==
/*  Tigase Jabber/XMPP Server
 *  Copyright (C) 2004-2012 "Artur Hefczyc" <artur.hefczyc@tigase.org>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. Look for COPYING file in the top folder.
 * If not, see http://www.gnu.org/licenses/.
 *
 * $Rev$
 * Last modified by $Author$
 * $Date$
 */
package tigase.server.bosh;

import java.util.TimerTask;
import tigase.server.Packet;
import tigase.server.xmppclient.SeeOtherHostIfc;
import tigase.xmpp.BareJID;

/**
 * Describe interface BoshSessionTaskHandler here.
 *
 *
 * Created: Sat Aug  4 10:39:21 2007
 *
 * @author <a href="mailto:artur.hefczyc@tigase.org">Artur Hefczyc</a>
 * @version $Rev$
 */
public interface BoshSessionTaskHandler {

	BoshTask scheduleTask( BoshSession bs, long delay );

	BoshSendQueueTask scheduleSendQueueTask( BoshSession tt, long delay );

	void cancelTask( BoshTask bs );

	void cancelSendQueueTask( BoshSendQueueTask bt );

	void writeRawData( BoshIOService ios, String data );

	boolean addOutStreamOpen( Packet packet, BoshSession bs );

	boolean addOutStreamClosed( Packet packet, BoshSession bs );

	BareJID getDefHostName();
	
	BareJID getSeeOtherHostForJID( BareJID userId, SeeOtherHostIfc.Phase ph );
}
